<?php
// $Id: udheader_settings.inc,v 1.1.2.1.2.2 2010/07/19 21:28:45 mtecknology Exp $

/**
 * @file
 * Module Settings
 */

/**
 * Core settings function
 */
function udheader_admin_settings() {
  $tid = intval(arg(3)); // @deprecated arg()
  if ($tid > 0) {
    $edit = db_fetch_array(db_query('SELECT * FROM {udheader} WHERE tid = %d', $tid));
    $output .= drupal_get_form('udheader_linkform', $edit, TRUE);
  }
  else {
    $output .= drupal_get_form('udheader_linkform', $edit, FALSE);
    $output .= t('<h2>Header Maps</h2>');
    $output .= udheader_view_list();
  }
  return $output;
}

/**
 * Build form to add/edit location links
 */
function udheader_linkform(&$form_state, $edit = array(), $individual = FALSE) {
  // Get available node types
  $node_types = node_get_types('names');
  $node_types['udheader_default'] .= 'Default';

  // Get left images
  $dir =  drupal_get_path('module', 'udheader') . "/images/left/";
  $handle = opendir($dir);
  while (false !== ($file = readdir($handle))) {
    if ($file != '.' && $file != '..') {
      $images['left'][$file] = $file;
    }
  }
  closedir($handle);

  // Get center images
  $dir =  drupal_get_path('module', 'udheader') . "/images/center/";
  $handle = opendir($dir);
  while (false !== ($file = readdir($handle))) {
    if ($file != '.' && $file != '..') {
      $images['center'][$file] = $file;
    }
  }
  closedir($handle);

  // Get right images
  $dir =  drupal_get_path('module', 'udheader') . "/images/right/";
  $handle = opendir($dir);
  while (false !== ($file = readdir($handle))) {
    if ($file != '.' && $file != '..') {
      $images['right'][$file] = $file;
    }
  }
  closedir($handle);

  $form = array();

  $c = $edit['tid'] > 0 ? FALSE : TRUE;  $t = $edit['tid'] > 0 ? 'Edit' : 'Add';
  $form['udheader'] = array(
    '#type' => 'fieldset',
    '#title' => t($t . ' Header'),
    '#collapsible' => $c,
    '#collapsed' => $c,
    '#tree' => FALSE,
  );
  $form['udheader']['tid'] = array(
    '#type' => 'hidden',
    '#value' => $edit['tid']
  );
  $form['udheader']['node'] = array(
    '#type' => 'select',
    '#title' => t('Node Type'),
    '#options' => $node_types,
    '#default_value' => t($edit['node']),
    '#description' => t('Select the node type which the header will be applied for.'),
  );
  $form['udheader']['left'] = array(
    '#type' => 'select',
    '#title' => t('Left Image'),
    '#options' => $images['left'],
    '#default_value' => t($edit['leftimg']),
    '#description' => t('Select the image to be used on the left side of the header.'),
  );
  $form['udheader']['center'] = array(
    '#type' => 'select',
    '#title' => t('Center Image'),
    '#options' => $images['center'],
    '#default_value' => t($edit['centerimg']),
    '#description' => t('Select the image to be used in the center of the header.'),
  );
  $form['udheader']['centertext'] = array(
    '#type' => 'textarea',
    '#title' => t('Text to be displayed in the center of the masthead'),
    '#default_value' => t($edit['centertext']),
  );
  $form['udheader']['right'] = array(
    '#type' => 'select',
    '#title' => t('Right Image'),
    '#options' => $images['right'],
    '#default_value' => t($edit['rightimg']),
    '#description' => t('Select the image to be used on the right side of the header.'),
  );
  $form['udheader']['righttext'] = array(
    '#type' => 'textarea',
    '#title' => t('Text to be displayed in the right part of the masthead'),
    '#default_value' => $edit['righttext'],
  );
  $form['udheader']['submit'] = array(
    '#type' => 'submit',
    '#value' => $edit['tid'] > 0 ? 'Update' : 'Add'
  );

  if ($individual) {
    $form['udheader']['delete'] = array(
      '#type' => 'submit',
      '#value' => 'Delete',
    );
  }

  return $form;
}

/**
 * Build list of existing linked locations
 */
function udheader_view_list() {
  $imgmaps = db_query('SELECT * FROM {udheader}');
  $rows = array();
  $headers = array('Node Type', 'Left Image', 'Center Image', 'Right Image', 'Edit');

  while ($imgmap = db_fetch_object($imgmaps)) {
    $tid = strval($imgmap->tid);
    array_push($rows, array(
      t($imgmap->node),
      t($imgmap->leftimg),
      t($imgmap->centerimg),
      t($imgmap->rightimg),
      l(t('edit'), 'admin/settings/udheader/'. $tid),
    )
    );
  }
  return theme('table', $headers, $rows);
}

/**
 * Add/Delete/Update location link to database
 */
function udheader_linkform_submit($form, &$form_state) {

  $form_state['redirect'] = 'admin/settings/udheader';

  $op  = $form_state['clicked_button']['#post']['op'];
  $tid = $form_state['clicked_button']['#post']['tid'];
  $node = $form_state['clicked_button']['#post']['node'];
  $left = $form_state['clicked_button']['#post']['left'];
  $center = $form_state['clicked_button']['#post']['center'];
  $centertext = $form_state['clicked_button']['#post']['centertext'];
  $right = $form_state['clicked_button']['#post']['right'];
  $righttext = $form_state['clicked_button']['#post']['righttext'];

  // Update
  if ($op == 'Update') {
    $rslt = db_query('UPDATE {udheader} SET node="%s", leftimg="%s", centerimg="%s", centertext="%s", rightimg="%s", righttext="%s" WHERE tid=%d', $node, $left, $center, $centertext, $right, $righttext, $tid);
  }

  // Delete
  if ($op == 'Delete') {
    $rslt = db_query('DELETE FROM {udheader} WHERE tid=%d', $tid);
  }

  // Add
  if ($op == 'Add') {
    $rslt = db_query('INSERT INTO {udheader} (node, leftimg, centerimg, centertext, rightimg, righttext) VALUES ("%s", "%s", "%s", "%s", "%s", "%s")', $node, $left, $center, $centertext, $right, $righttext);
  }

  // Check Result
  if ('1' == $rslt) {
    drupal_set_message(t('Record modification made.'));
    return TRUE;
  }
  else {
    trigger_error(t('Record modification failed.'));
    return FALSE;
  }
}
